<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class Client extends CI_Controller 
{

	public function __construct() 
	{
		parent::__construct();
		$this->load->model("user_model");
		$this->load->model("projects_model");
		$this->load->model("documents_model");
		$this->load->model("knowledge_model");
		$this->load->model("contact_model");
		$this->load->model("home_model");
		$this->load->model("news_model");
		$this->template->set_error_view("error/client_error.php");
		$this->template->set_layout("layout/client_layout.php");
	}

	public function index() 
	{
		$this->template->set_page_title("Documentation Projects");

		$projects = $this->projects_model->get_all_projects();

		$this->template->loadContent("client/index.php", array(
			"projects" => $projects
			)
		);
	}

	public function view($projectid) 
	{
		$projectid = intval($projectid);
		$project = $this->projects_model->get_project($projectid);
		if($project->num_rows() == 0) {
			$this->template->error(lang("error_68"));
		}
		$project = $project->row();

		$this->load_sidebar($project->ID);

		$this->template->loadContent("client/view.php", array(
			"project" => $project
			)
		);
	}

	public function download($projectid) 
	{
		$projectid = intval($projectid);
		$project = $this->projects_model->get_project($projectid);
		if($project->num_rows() == 0) {
			$this->template->error(lang("error_68"));
		}
		$project = $project->row();
		$documents = $this->documents_model->get_documents_no_limit_links($projectid);
		$this->load_sidebar_download($documents);
		$this->template->loadData("hideadmin", 1);
		$this->template->loadContent("client/download.php", array(
			"project" => $project,
			"documents" => $documents
			)
		);
	}

	public function document($projectid, $id) 
	{
		$projectid = intval($projectid);
		$project = $this->projects_model->get_project($projectid);
		if($project->num_rows() == 0) {
			$this->template->error(lang("error_68"));
		}
		$project = $project->row();

		$this->load_sidebar($project->ID);
		$this->template->loadData("hideadmin", 1);

		$id = intval($id);
		$document = $this->documents_model->get_document($id);
		if($document->num_rows() == 0) {
			$this->template->error(lang("error_69"));
		}
		$document = $document->row();

		if($document->projectid != $projectid) 
		{
			$this->template->error(lang("error_70"));
		}

		if($document->link_documentid > 0) {
			$files = $this->documents_model->get_files($document->link_documentid);
		} else {
			$files = $this->documents_model->get_files($id);
		}

		$this->template->loadContent("client/document.php", array(
			"project" => $project,
			"document" => $document,
			"files" => $files,
			"hideadmin" => 1
			)
		);
	}

	private function load_sidebar($projectid) 
	{
		$this->template->loadSidebar("client/sidebar.php");
		$documents = $this->documents_model->get_documents_no_limit_links($projectid);
		$this->template->loadData("documents", $documents);
	}

	private function load_sidebar_download($documents) 
	{
		$this->template->loadSidebar("client/download_sidebar.php");
		$this->template->loadData("documents", $documents);
	}

	public function knowledge($projectid) 
	{
		$projectid = intval($projectid);
		$project = $this->projects_model->get_project($projectid);
		if($project->num_rows() == 0) {
			$this->template->error(lang("error_68"));
		}
		$project = $project->row();
		$this->load_sidebar($project->ID);

		if(!$project->enable_knowledge) {
			$this->template->error(lang("error_71"));
		}

		$categories = $this->knowledge_model
			->get_categories_projectid($projectid);

		$articles = $this->knowledge_model->get_recent_articles($projectid, 5);

		$this->template->loadContent("client/knowledge.php", array(
			"project" => $project,
			"categories" => $categories,
			"articles" => $articles
			)
		);
	}

	public function knowledge_cat($projectid, $id, $page = 0) 
	{
		$projectid = intval($projectid);
		$project = $this->projects_model->get_project($projectid);
		if($project->num_rows() == 0) {
			$this->template->error(lang("error_68"));
		}
		$project = $project->row();
		$this->load_sidebar($project->ID);

		if(!$project->enable_knowledge) {
			$this->template->error(lang("error_71"));
		}

		$page = intval($page);

		$id = intval($id);
		$category = $this->knowledge_model->get_category($id);
		if($category->num_rows() == 0) {
			$this->template->error(lang("error_72"));
		}
		$category = $category->row();

		// Check category is part of this project
		$procat = $this->knowledge_model->get_project_cat($projectid, $id);
		if($procat->num_rows() == 0) {
			$this->template->error(lang("error_72"));
		}


		$this->template->loadContent("client/knowledge_cat.php", array(
			"project" => $project,
			"category" => $category,
			)
		);
	}

	public function documents_page($projectid =0, $catid =0) 
	{
		$projectid = intval($projectid);
		$catid = intval($catid);
		if($projectid == 0) {
			$projectid = $this->user->info->active_projectid;
		}

		$this->load->library("datatables");

		$this->datatables->set_default_order("knowledge_articles.last_updated", "desc");

		// Set page ordering options that can be used
		$this->datatables->ordering(
			array(
				 0 => array(
				 	"knowledge_articles.title" => 0
				 ),
				 1 => array(
				 	"knowledge_categories.name" => 0
				 ),
				 2 => array(
				 	"users.username" => 0
				 ),
				 3 => array(
				 	"knowledge_articles.last_updated" => 0
				 )
			)
		);

		$this->datatables->set_total_rows(
			$this->knowledge_model
			->get_total_articles_count($projectid, $catid)
		);
		$articles = $this->knowledge_model->get_articles($projectid, 
			$catid, $this->datatables);

		foreach($articles->result() as $r) {
			$this->datatables->data[] = array(
				$r->title,
				'<a href="'.site_url("client/knowledge_cat/".$projectid."/" . $r->categoryid).'">'.$r->cat_name.'</a>',
				date($this->settings->info->date_format, $r->last_updated),
				'<a href="'.site_url("client/knowledge_article/" . $projectid . "/" . $r->ID).'" class="btn btn-info btn-xs" >'.lang("ctn_422").'</a>'
			);
		}
		echo json_encode($this->datatables->process());
	}

	public function knowledge_all($projectid) 
	{
		$projectid = intval($projectid);
		$project = $this->projects_model->get_project($projectid);
		if($project->num_rows() == 0) {
			$this->template->error(lang("error_68"));
		}
		$project = $project->row();
		$this->load_sidebar($project->ID);

		$this->template->loadContent("client/knowledge_all.php", array(
			"project" => $project,
			)
		);
	}

	public function knowledge_article($projectid, $id) 
	{
		$projectid = intval($projectid);
		$project = $this->projects_model->get_project($projectid);
		if($project->num_rows() == 0) {
			$this->template->error(lang("error_68"));
		}
		$project = $project->row();
		$this->load_sidebar($project->ID);

		if(!$project->enable_knowledge) {
			$this->template->error(lang("error_71"));
		}

		$id = intval($id);
		$article = $this->knowledge_model->get_article($id);
		if($article->num_rows() == 0) {
			$this->template->error(lang("error_73"));
		}
		$article = $article->row();

		$this->template->loadContent("client/knowledge_article.php", array(
			"project" => $project,
			"article" => $article
			)
		);

	}


	public function contact($projectid) 
	{
		$projectid = intval($projectid);
		$project = $this->projects_model->get_project($projectid);
		if($project->num_rows() == 0) {
			$this->template->error(lang("error_68"));
		}
		$project = $project->row();
		$this->load_sidebar($project->ID);

		if(!$project->enable_contact) {
			$this->template->error(lang("error_75"));
		}

		$contact = $this->contact_model->get_fields_project($projectid);

		$this->template->loadContent("client/contact.php", array(
			"project" => $project,
			"contact" => $contact
			)
		);
	}


	public function contact_pro($projectid) 
	{
		$request = $this->user_model->get_user_event("contact_us");
		if($request->num_rows() > 0) {
			$request = $request->row();
			if($request->timestamp + (15*60) > time()) {
				$this->template->error(lang("error_76"));
			}
		}

		$projectid = intval($projectid);
		$project = $this->projects_model->get_project($projectid);
		if($project->num_rows() == 0) {
			$this->template->error(lang("error_68"));
		}
		$project = $project->row();
		$this->load_sidebar($project->ID);

		if(!$project->enable_contact) {
			$this->template->error(lang("error_75"));
		}

		$this->load->helper('email');

		$user_data = array();
		$contact = $this->contact_model->get_fields_project($projectid);
		foreach($contact->result() as $r) {
			if(isset($_POST['custom_field_' . $r->ID]) &&
				 !empty($_POST['custom_field_' . $r->ID])) {
				$value = $this->common->nohtml(
						$this->input->post("custom_field_" . $r->ID));
				if($r->type == 4) {
					if (!valid_email($value)) {
						$this->template->error(lang("error_77"));
					}
				}
				$user_data[$r->name] = $value;
			} else {
				if($r->required) {
					$this->template->error(lang("error_78"));
				}
			}
		}

		// Send email
		$this->load->model("home_model");
		$email_template = $this->home_model->get_email_template(3);
		if($email_template->num_rows() == 0) {
			$this->template->error(lang("error_48"));
		}
		$email_template = $email_template->row();

		$email_template->message = $this->common->replace_keywords(array(
			"[NAME]" => $this->settings->info->site_name,
			"[SITE_URL]" => site_url(),
			"[EMAIL_LINK]" => site_url(),
			"[SITE_NAME]" =>  $this->settings->info->site_name
			),
		$email_template->message);

		$email_template->message .= "[USER_DATA]<br /><br />";

		foreach($user_data as $k=>$v) {
			$email_template->message .= $k . ": " . $v . "<br />";
		}

		$email_template->message .= "<br />[END USER_DATA]";

		$this->common->send_email($email_template->title,
			 $email_template->message, $project->contact_email);

		$this->user_model->add_user_event(array(
			"event" => "contact_us",
			"IP" => $_SERVER['REMOTE_ADDR'],
			"timestamp" => time()
			)
		);

		$this->session->set_flashdata("globalmsg", 
			lang("success_33"));
		redirect(site_url("client/contact/" . $projectid));
	}

	public function news($projectid, $page= 0) 
	{
		$projectid = intval($projectid);
		$page = intval($page);
		$project = $this->projects_model->get_project($projectid);
		if($project->num_rows() == 0) {
			$this->template->error(lang("error_68"));
		}
		$project = $project->row();
		$this->load_sidebar($project->ID);

		if(!$project->enable_news) {
			$this->template->error(lang("error_110"));
		}

		$news = $this->news_model->get_project_news($projectid, $page);

		// * Pagination *//
		$this->load->library('pagination');
		$config['base_url'] = site_url("client/news/" . $projectid);
		$config['total_rows'] = $this->news_model
			->get_total_news_count($projectid);
		$config['per_page'] = 10;
		$config['uri_segment'] = 4;
		include (APPPATH . "/config/page_config.php");
		$this->pagination->initialize($config);

		$this->template->loadContent("client/news.php", array(
			"project" => $project,
			"news" => $news
			)
		);
	}

}

?>