<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class Contact extends CI_Controller 
{

	public function __construct() 
	{
		parent::__construct();
		$this->load->model("user_model");
		$this->load->model("projects_model");
		$this->load->model("contact_model");


		if(!$this->user->loggedin) {
			$this->template->error(lang("error_1"));
		}

		if(!$this->common->has_permissions(array("admin", "contact_manage"), 
			$this->user)) {
			$this->template->error(lang("error_79"));
		}
		
		// If the user does not have premium. 
		// -1 means they have unlimited premium
		if($this->settings->info->global_premium && 
			($this->user->info->premium_time != -1 && 
				$this->user->info->premium_time < time()) ) {
			$this->session->set_flashdata("globalmsg", lang("success_29"));
			redirect(site_url("funds/plans"));
		}
	}

	public function index($projectid = 0, $page = 0) 
	{
		$this->template->loadData("activeLink", 
			array("contact" => array("general" => 1)));

		$projectid = intval($projectid);
		$page = intval($page);

		if($projectid == 0) {
			$projectid = $this->user->info->active_projectid;
		}

		$fields = $this->contact_model->get_fields($projectid, $page);
		// * Pagination *//
		$this->load->library('pagination');
		$config['base_url'] = site_url("contact/index/" . $projectid);
		$config['total_rows'] = $this->contact_model
			->get_total_fields_count($projectid);
		$config['per_page'] = 15;
		$config['uri_segment'] = 4;
		include (APPPATH . "/config/page_config.php");
		$this->pagination->initialize($config);

		$this->template->loadContent("contact/index.php", array(
			"fields" => $fields
			)
		);
	}

	public function add() 
	{
		$this->template->loadData("activeLink", 
			array("contact" => array("general" => 1)));
		$projects = $this->projects_model->get_all_projects_contact();
		$this->template->loadContent("contact/add.php", array(
			"projects" => $projects
			)
		);
	}

	public function add_pro() 
	{
		$name = $this->common->nohtml($this->input->post("name"));
		$type = intval($this->input->post("type"));
		$help_text = $this->common->nohtml($this->input->post("help_text"));
		$select_data = $this->common->nohtml($this->input->post("select_data"));
		$required = intval($this->input->post("required"));
		$projectid = intval($this->input->post("projectid"));

		if(empty($name)) {
			$this->template->error(lang("error_80"));
		}
		if($type < 0 || $type > 4) {
			$this->template->error(lang("error_81"));
		}

		if($projectid > 0) {
			$project = $this->projects_model->get_project($projectid);
			if($project->num_rows() == 0) {
				$this->template->error(lang("error_82"));
			}
			$project = $project->row();
			if(!$project->enable_contact) {
				$this->template->error(lang("error_83"));
			}
		}

		$this->contact_model->add_field(array(
			"name" => $name,
			"type" => $type,
			"help_text" => $help_text,
			"select_data" => $select_data,
			"required" => $required,
			"projectid" => $projectid,
			"userid" => $this->user->info->ID,
			"timestamp" => time()
			)
		);

		$this->session->set_flashdata("globalmsg", 
			lang("success_34"));
		redirect(site_url("contact"));
	}

	public function delete_field($id, $hash) 
	{
		if($hash != $this->security->get_csrf_hash()) 
		{
			$this->template->error(lang("error_6"));
		}
		$id = intval($id);
		$field = $this->contact_model->get_field($id);
		if($field->num_rows() == 0) {
			$this->template->error(lang("error_84"));
		}

		$this->contact_model->delete_field($id);
		$this->session->set_flashdata("globalmsg", 
			"Field was deleted!");
		redirect(site_url("contact"));
	}

	public function edit_field($id) 
	{
		$id = intval($id);
		$field = $this->contact_model->get_field($id);
		if($field->num_rows() == 0) {
			$this->template->error(lang("error_84"));
		}

		$this->template->loadData("activeLink", 
			array("contact" => array("general" => 1)));
		$projects = $this->projects_model->get_all_projects_contact();

		$this->template->loadContent("contact/edit_field.php", array(
			"projects" => $projects,
			"field" => $field->row()
			)
		);
	}

	public function edit_field_pro($id) 
	{
		$id = intval($id);
		$field = $this->contact_model->get_field($id);
		if($field->num_rows() == 0) {
			$this->template->error(lang("error_84"));
		}

		$name = $this->common->nohtml($this->input->post("name"));
		$type = intval($this->input->post("type"));
		$help_text = $this->common->nohtml($this->input->post("help_text"));
		$select_data = $this->common->nohtml($this->input->post("select_data"));
		$required = intval($this->input->post("required"));
		$projectid = intval($this->input->post("projectid"));

		if(empty($name)) {
			$this->template->error(lang("error_80"));
		}
		if($type < 0 || $type > 4) {
			$this->template->error(lang("error_81"));
		}

		if($projectid > 0) {
			$project = $this->projects_model->get_project($projectid);
			if($project->num_rows() == 0) {
				$this->template->error(lang("error_82"));
			}
			$project = $project->row();
			if(!$project->enable_contact) {
				$this->template->error(lang("error_83"));
			}
		}

		$this->contact_model->update_field($id, array(
			"name" => $name,
			"type" => $type,
			"help_text" => $help_text,
			"select_data" => $select_data,
			"required" => $required,
			"projectid" => $projectid
			)
		);

		$this->session->set_flashdata("globalmsg", 
			lang("success_35"));
		redirect(site_url("contact"));
	}


}

?>