<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class Documents extends CI_Controller 
{

	public function __construct() 
	{
		parent::__construct();
		$this->load->model("user_model");
		$this->load->model("documents_model");
		$this->load->model("projects_model");

		if(!$this->user->loggedin) $this->template->error(lang("error_1"));
		if(!$this->common->has_permissions(array("admin", "documentation_manage"), 
			$this->user)) {
			$this->template->error(lang("error_79"));
		}
	}

	public function index($projectid = 0, $page = 0) 
	{
		$this->template->loadData("activeLink", 
			array("documents" => array("general" => 1)));

		$projects = $this->projects_model->get_all_projects_documentation();

		$this->template->loadContent("documents/index.php", array(
			"projectid" => $projectid,
			"projects" => $projects
			)
		);
	}

	public function document_page($projectid = 0) 
	{
		$projectid = intval($projectid);

		if($projectid == 0) {
			$projectid = $this->user->info->active_projectid;
		}

		$this->load->library("datatables");

		$this->datatables->set_default_order("documents.last_updated", "desc");

		// Set page ordering options that can be used
		$this->datatables->ordering(
			array(
				 0 => array(
				 	"documents.title" => 0
				 ),
				 1 => array(
				 	"projects.project_name" => 0
				 ),
				 2 => array(
				 	"users.username" => 0
				 ),
				 3 => array(
				 	"documents.timestamp" => 0
				 ),
				 4 => array(
				 	"documents.last_updated" => 0
				 ),

			)
		);

		$this->datatables->set_total_rows(
			$this->documents_model
			->get_total_documents_count($projectid)
		);
		$documents = $this->documents_model->get_documents($projectid, $this->datatables);

		foreach($documents->result() as $r) {

			$title = $r->title;
			if($r->link_documentid > 0) {
				$title .= ' <a href="'.site_url("documents/edit/" . $r->link_documentid).'">'. lang("ctn_413") .' ['. $r->link_title .']</a>';
			}

			$options = '';
			if($r->link_documentid > 0) {
				$options .= '<a href="'.site_url("documents/edit/" . $r->link_documentid) .'" class="btn btn-warning btn-xs">'. lang("ctn_414") .'</a> ';
			}
			$options .='<a href="'. site_url("documents/edit/" . $r->ID).'" class="btn btn-warning btn-xs" title="'.lang("ctn_55").'" data-toggle="tooltip" data-placement="bottom"><span class="glyphicon glyphicon-cog"></span></a> <a href="'. site_url("documents/delete/" . $r->ID . "/" . $this->security->get_csrf_hash()) .'" class="btn btn-danger btn-xs" onclick="return confirm(\''.lang("ctn_317").'\')" title="'.lang("ctn_57").'" data-toggle="tooltip" data-placement="bottom"><span class="glyphicon glyphicon-trash"></span></a>';
			
			$this->datatables->data[] = array(
				$title,
				$r->project_name,
				$this->common->get_user_display(array("username" => $r->username, "avatar" => $r->avatar, "online_timestamp" => $r->online_timestamp)),
				date($this->settings->info->date_format, $r->timestamp),
				date($this->settings->info->date_format, $r->last_updated),
				$options
			);
		}
		echo json_encode($this->datatables->process());
	}


	public function add() 
	{	
		$this->template->loadExternal(
			'<script src="//cdn.ckeditor.com/4.5.8/standard/ckeditor.js">
			</script>'
		);
		$this->template->loadData("activeLink", 
			array("documents" => array("general" => 1)));
		$projects = $this->projects_model->get_all_projects_documentation();
		$this->template->loadContent("documents/add.php", array(
			"projects" => $projects
			)
		);
	}

	public function add_document()
	{
		$name = $this->common->nohtml($this->input->post("name"));
		$document = $this->lib_filter->go($this->input->post("document"));
		$projectid = intval($this->input->post("projectid"));

		$link_documentid = intval(
			$this->input->post("link_documentid"));

		if(empty($name)) {
			$this->template->error(lang("error_85"));
		}

		$project = $this->projects_model->get_project($projectid);
		if($project->num_rows() == 0) {
			$this->template->error(lang("error_82"));
		}
		$project = $project->row();
		if(!$project->enable_documentation) {
			$this->template->error(lang("error_86"));
		}

		if($link_documentid > 0) {
			$document_link = $this->documents_model->get_document($link_documentid);
			if($document_link->num_rows() == 0) {
				$this->template->error(lang("error_87"));
			}
			$dl = $document_link->row();
			if($dl->link_documentid >0) {
				$this->template->error(lang("error_88"));
			}
		}

		$documentid = $this->documents_model->add_document(array(
			"title" => $name,
			"document" => $document,
			"projectid" => $projectid,
			"userid" => $this->user->info->ID,
			"timestamp" => time(),
			"last_updated" => time(),
			"link_documentid" => $link_documentid
			)
		);

		$file_count = intval($this->input->post("file_count"));
		for($i=1;$i<=$file_count;$i++) {
			if(isset($_FILES['userfile_' . $i]) && !empty($_FILES['userfile_' . $i]['tmp_name']) ) 
			{
				$this->load->library("upload");
				$this->upload->initialize(array(
				   "upload_path" => $this->settings->info->upload_path,
			       "overwrite" => FALSE,
			       "max_filename" => 300,
			       "encrypt_name" => TRUE,
			       "remove_spaces" => TRUE,
			       "allowed_types" => $this->settings->info->file_types,
			       "max_size" => $this->settings->info->file_size,
					)
				);

				if ( ! $this->upload->do_upload('userfile_' . $i))
	            {
	                    $this->template->error(lang("error_89") . "<br /><br />" .
	                    	 $this->upload->display_errors());
	            }

	            $data = $this->upload->data();
	            $name = $this->common
	            	->nohtml(trim($data['orig_name']));

	            $this->documents_model->add_file(array(
	            	"file_name" => $data['file_name'],
	            	"name" => $name,
	            	"documentid" => $documentid,
	            	"file_type" => $data['file_type'],
	            	"extension" => $data['file_ext'],
	            	"file_size" => $data['file_size'],
	            	"userid" => $this->user->info->ID,
	            	"timestamp" => time()
	            	)
	            );
			}
		}

		$this->session->set_flashdata("globalmsg", lang("success_36"));
		redirect(site_url("documents"));
	}

	public function edit($id) 
	{
		$id = intval($id);
		$document = $this->documents_model->get_document($id);
		if($document->num_rows() == 0) {
			$this->template->error(lang("error_90"));
		}

		$this->template->loadExternal(
			'<script src="//cdn.ckeditor.com/4.5.8/standard/ckeditor.js">
			</script>'
		);
		$this->template->loadData("activeLink", 
			array("documents" => array("general" => 1)));
		$projects = $this->projects_model->get_all_projects_documentation();
		$files = $this->documents_model->get_files($id);

		$this->template->loadContent("documents/edit.php", array(
			"projects" => $projects,
			"document" => $document->row(),
			"files" => $files
			)
		);

	}

	public function edit_pro($id) 
	{
		$id = intval($id);
		$document = $this->documents_model->get_document($id);
		if($document->num_rows() == 0) {
			$this->template->error(lang("error_90"));
		}

		$name = $this->common->nohtml($this->input->post("name"));
		$document = $this->lib_filter->go($this->input->post("document"));
		$projectid = intval($this->input->post("projectid"));
		$link_documentid = intval(
			$this->input->post("link_documentid"));

		if(empty($name)) {
			$this->template->error(lang("error_85"));
		}

		$project = $this->projects_model->get_project($projectid);
		if($project->num_rows() == 0) {
			$this->template->error(lang("error_82"));
		}
		$project = $project->row();
		if(!$project->enable_documentation) {
			$this->template->error(lang("error_86"));
		}

		if($link_documentid > 0) {
			$document_link = $this->documents_model->get_document($link_documentid);
			if($document_link->num_rows() == 0) {
				$this->template->error(lang("error_87"));
			}
			$dl = $document_link->row();
			if($dl->link_documentid >0) {
				$this->template->error(lang("error_88"));
			}
			if($link_documentid == $id) {
				$this->template->error(lang("error_91"));
			}
		}

		$this->documents_model->update_document($id, array(
			"title" => $name,
			"document" => $document,
			"projectid" => $projectid,
			"last_updated" => time(),
			"link_documentid" => $link_documentid
			)
		);

		$documentid = $id;

		$file_count = intval($this->input->post("file_count"));
		for($i=1;$i<=$file_count;$i++) {
			if(isset($_FILES['userfile_' . $i]) && !empty($_FILES['userfile_' . $i]['tmp_name']) ) 
			{
				$this->load->library("upload");
				$this->upload->initialize(array(
				   "upload_path" => $this->settings->info->upload_path,
			       "overwrite" => FALSE,
			       "max_filename" => 300,
			       "encrypt_name" => TRUE,
			       "remove_spaces" => TRUE,
			       "allowed_types" => $this->settings->info->file_types,
			       "max_size" => $this->settings->info->file_size,
					)
				);

				if ( ! $this->upload->do_upload('userfile_' . $i))
	            {
	                    $this->template->error(lang("error_89") . "<br /><br />" .
	                    	 $this->upload->display_errors());
	            }

	            $data = $this->upload->data();
	            $name = $this->common
	            	->nohtml(trim($data['orig_name']));

	            $this->documents_model->add_file(array(
	            	"file_name" => $data['file_name'],
	            	"name" => $name,
	            	"documentid" => $documentid,
	            	"file_type" => $data['file_type'],
	            	"extension" => $data['file_ext'],
	            	"file_size" => $data['file_size'],
	            	"userid" => $this->user->info->ID,
	            	"timestamp" => time()
	            	)
	            );
			}
		}

		$this->session->set_flashdata("globalmsg", lang("success_37"));
		redirect(site_url("documents"));
	}

	public function delete($id, $hash) 
	{
		if($hash != $this->security->get_csrf_hash()) {
			$this->template->error(lang("error_6"));
		}
		$id = intval($id);
		$document = $this->documents_model->get_document($id);
		if($document->num_rows() == 0) {
			$this->template->error(lang("error_90"));
		}

		$this->documents_model->delete_document($id);
		$this->session->set_flashdata("globalmsg", lang("success_38"));
		redirect(site_url("documents"));
	}

	public function delete_file($id, $hash) 
	{
		if($hash != $this->security->get_csrf_hash()) {
			$this->template->error(lang("error_6"));
		}
		$id = intval($id);
		$file = $this->documents_model->get_file($id);
		if($file->num_rows() == 0) {
			$this->template->error(lang("error_92"));
		}
		$file =$file->row();

		$this->documents_model->delete_file($id);
		$this->session->set_flashdata("globalmsg", lang("success_39"));
		redirect(site_url("documents/edit/" . $file->documentid));
	}

	public function get_documents($projectid) 
	{
		$projectid = intval($projectid);
		$documents = $this->documents_model->get_documents_no_limit($projectid);
		$this->template->loadAjax("documents/ajax_documents_list.php", array(
			"documents" => $documents,
			)
		);
	}

	public function order($projectid = 0 ) {
		$this->template->loadData("activeLink", 
			array("documents" => array("order" => 1)));
		$projectid = intval($projectid);
		if($projectid == 0) {
			$projectid = $this->user->info->active_projectid;
		}

		if($projectid == 0) {
			// Select project
			$projects = $this->projects_model->get_all_projects_documentation();
			$this->template->loadContent("documents/order_select.php", array(
			"projects" => $projects
				)
			);
		} else {
			$project = $this->projects_model->get_project($projectid);
			if($project->num_rows() == 0) {
				$this->template->error(lang("error_82"));
			}

			$documents = $this->documents_model->get_documents_order($projectid);
			$this->template->loadContent("documents/order.php", array(
				"project" => $project->row(),
				"documents" => $documents
				)
			);
		}
	}

	public function update_order($projectid) 
	{
		$project = $this->projects_model->get_project($projectid);
		if($project->num_rows() == 0) {
			$this->template->error(lang("error_82"));
		}

		$documents = $this->documents_model->get_documents_order($projectid);
		foreach($documents->result() as $r) {
			$position = $this->get_position($_GET['document'], $r->ID);
			$this->documents_model->update_document($r->ID, array(
				"sort_no" => $position
				)
			);
		}
		$this->session->set_flashdata("globalmsg", lang("success_40"));
		redirect(site_url("documents/order/" . $projectid));

	}

	private function get_position($array, $id) 
	{
		$i=0;
		if(!is_array($array)) return 0;
		foreach($array as $order) {
			if($order == $id) {
				return $i;
			}
			$i++;
		}
		return 0;
	}

}

?>