<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class Knowledge extends CI_Controller 
{

	public function __construct() 
	{
		parent::__construct();
		$this->load->model("user_model");
		$this->load->model("knowledge_model");
		$this->load->model("projects_model");

		if(!$this->user->loggedin) $this->template->error(lang("error_1"));
		if(!$this->common->has_permissions(array("admin", "knowledge_manage"), 
			$this->user)) {
			$this->template->error(lang("error_79"));
		}
	}


	public function index($projectid = 0, $catid =0) 
	{
		
		$projectid = intval($projectid);
		$catid = intval($catid);
		if($projectid == 0) {
			$projectid = $this->user->info->active_projectid;
		}

		$this->template->loadData("activeLink", 
			array("knowledge" => array("general" => 1)));

		$projects = $this->projects_model->get_all_projects_knowledge();


		$this->template->loadContent("knowledge/index.php", array(
			"projectid" => $projectid,
			"projects" => $projects,
			"catid" => $catid
			)
		);
	}

	public function documents_page($projectid =0, $catid =0) 
	{
		$projectid = intval($projectid);
		$catid = intval($catid);
		if($projectid == 0) {
			$projectid = $this->user->info->active_projectid;
		}

		$this->load->library("datatables");

		$this->datatables->set_default_order("knowledge_articles.last_updated", "desc");

		// Set page ordering options that can be used
		$this->datatables->ordering(
			array(
				 0 => array(
				 	"knowledge_articles.title" => 0
				 ),
				 1 => array(
				 	"knowledge_categories.name" => 0
				 ),
				 2 => array(
				 	"users.username" => 0
				 ),
				 3 => array(
				 	"knowledge_articles.last_updated" => 0
				 )
			)
		);

		$this->datatables->set_total_rows(
			$this->knowledge_model
			->get_total_articles_count($projectid, $catid)
		);
		$articles = $this->knowledge_model->get_articles($projectid, 
			$catid, $this->datatables);

		foreach($articles->result() as $r) {
			$this->datatables->data[] = array(
				$r->title,
				'<a href="'.site_url("knowledge/index/0/" . $r->categoryid).'">'.$r->cat_name.'</a>',
				$this->common->get_user_display(array("username" => $r->username, "avatar" => $r->avatar, "online_timestamp" => $r->online_timestamp)),
				date($this->settings->info->date_format, $r->last_updated),
				'<a href="'.site_url("knowledge/edit_article/" . $r->ID).'" class="btn btn-warning btn-xs" title="'.lang("ctn_55").'" data-toggle="tooltip" data-placement="bottom"><span class="glyphicon glyphicon-cog"></span></a> <a href="'.site_url("knowledge/delete_article/" . $r->ID . "/" . $this->security->get_csrf_hash()).'" class="btn btn-danger btn-xs" onclick="return confirm(\''.lang("ctn_317").'\')" title="'.lang("ctn_57").'" data-toggle="tooltip" data-placement="bottom"><span class="glyphicon glyphicon-trash"></span></a>'
			);
		}
		echo json_encode($this->datatables->process());
	}

	public function search() 
	{
		$this->template->loadData("activeLink", 
			array("knowledge" => array("general" => 1)));
		$type = intval($this->input->post("type"));
		$search = $this->common->nohtml($this->input->post("search"));

		if($type == 0) {
			$articles = $this->knowledge_model->get_articles_title($search);
		} elseif($type == 1) {
			$articles = $this->knowledge_model->get_articles_article($search);
		}

		$this->template->loadContent("knowledge/search.php", array(
			"articles" => $articles,
			"type" => $type,
			"search" => $search
			)
		);
	}

	public function add() 
	{
		$this->template->loadData("activeLink", 
			array("knowledge" => array("general" => 1)));
		$this->template->loadExternal(
			'<link href="'.base_url().'scripts/libraries/chosen/chosen.min.css" rel="stylesheet" type="text/css">
			<script type="text/javascript" src="'.base_url().
			'scripts/libraries/chosen/chosen.jquery.min.js"></script>
			<script src="//cdn.ckeditor.com/4.5.8/standard/ckeditor.js">
			</script>'
		);

		$projects = $this->projects_model->get_all_projects_knowledge();
		$categories = $this->knowledge_model->get_categories_all();
		$this->template->loadContent("knowledge/add.php", array(
			"projects" => $projects,
			"categories" => $categories
			)
		);
	}

	public function add_pro() 
	{
		$title = $this->common->nohtml($this->input->post("name"));
		$article = $this->lib_filter->go($this->input->post("article"));
		
		$categoryid = intval($this->input->post("categoryid"));
		$sticky = intval($this->input->post("sticky"));

		if($sticky < 0 || $sticky > 1) {
			$this->template->error(lang("error_93"));
		}

		if(empty($title)) {
			$this->template->error(lang("error_94"));
		}

		$uprojects = $this->input->post("projects");

		// Check ticket categories
		$projects= array();
		if($uprojects) {
			foreach($uprojects as $projectid) {
				$projectid = intval($projectid);
				if($projectid > 0) {
					$project = $this->projects_model->get_project($projectid);
					if($project->num_rows() == 0) {
						$this->template->error(lang("error_120"));
					}
					$project = $project->row();
					if(!$project->enable_knowledge) {
						$this->template->error(lang("error_95"));
					}
					$projects[] = $projectid;
				}
			}
		}

		$category = $this->knowledge_model->get_category($categoryid);
		if($category->num_rows() == 0) {
			$this->template->error(lang("error_72"));
		}

		$articleid = $this->knowledge_model->add_article(array(
			"categoryid" => $categoryid,
			"title" => $title,
			"article" => $article,
			"timestamp" => time(),
			"last_updated" => time(),
			"userid" => $this->user->info->ID,
			"sticky" => $sticky
			)
		);

		foreach($projects as $pid) {
			$this->knowledge_model->add_projects_to_article($pid, $articleid);
		}



		$this->session->set_flashdata("globalmsg", 
			lang("success_41"));
		redirect(site_url("knowledge"));
	}

	public function delete_article($id, $hash) 
	{
		if($hash != $this->security->get_csrf_hash()) {
			$this->template->error(lang("error_6"));
		}
		$id = intval($id);
		$article = $this->knowledge_model->get_article($id);
		if($article->num_rows() == 0) {
			$this->template->error(lang("error_73"));
		}

		$this->knowledge_model->delete_article($id);
		$this->session->set_flashdata("globalmsg", 
			lang("success_42"));
		redirect(site_url("knowledge"));
	}

	public function edit_article($id) 
	{
		$id = intval($id);
		$article = $this->knowledge_model->get_article($id);
		if($article->num_rows() == 0) {
			$this->template->error(lang("error_73"));
		}

		$this->template->loadData("activeLink", 
			array("knowledge" => array("general" => 1)));

		$this->template->loadExternal(
			'<link href="'.base_url().'scripts/libraries/chosen/chosen.min.css" rel="stylesheet" type="text/css">
			<script type="text/javascript" src="'.base_url().
			'scripts/libraries/chosen/chosen.jquery.min.js"></script>
			<script src="//cdn.ckeditor.com/4.5.8/standard/ckeditor.js">
			</script>'
		);
		$article = $article->row();

		$projects = $this->knowledge_model->get_article_projects($id);
		$categories = $this->knowledge_model->get_categories_all();

		$this->template->loadContent("knowledge/edit_article.php", array(
			"projects" => $projects,
			"article" => $article,
			"categories" => $categories
			)
		);
	}

	public function edit_article_pro($id) 
	{
		$id = intval($id);
		$article = $this->knowledge_model->get_article($id);
		if($article->num_rows() == 0) {
			$this->template->error(lang("error_73"));
		}

		$title = $this->common->nohtml($this->input->post("name"));
		$article = $this->lib_filter->go($this->input->post("article"));
		$categoryid = intval($this->input->post("categoryid"));
		$sticky = intval($this->input->post("sticky"));

		if($sticky < 0 || $sticky > 1) {
			$this->template->error(lang("error_93"));
		}

		if(empty($title)) {
			$this->template->error(lang("error_94"));
		}

		$uprojects = $this->input->post("projects");

		// Check ticket categories
		$projects= array();
		if($uprojects) {
			foreach($uprojects as $projectid) {
				$projectid = intval($projectid);
				if($projectid > 0) {
					$project = $this->projects_model->get_project($projectid);
					if($project->num_rows() == 0) {
						$this->template->error(lang("error_120"));
					}
					$project = $project->row();
					if(!$project->enable_knowledge) {
						$this->template->error(lang("error_95"));
					}
					$projects[] = $projectid;
				}
			}
		}
	

		$category = $this->knowledge_model->get_category($categoryid);
		if($category->num_rows() == 0) {
			$this->template->error(lang("error_72"));
		}
		

		$this->knowledge_model->update_article($id, array(
			"categoryid" => $categoryid,
			"title" => $title,
			"article" => $article,
			"last_updated" => time(),
			"sticky" => $sticky
			)
		);

		$this->knowledge_model->delete_article_projects($id);

		foreach($projects as $pid) {
			$this->knowledge_model->add_projects_to_article($pid, $id);
		}

		$this->session->set_flashdata("globalmsg", 
			lang("success_43"));
		redirect(site_url("knowledge"));
	}

	public function get_categories($projectid) 
	{
		$projectid = intval($projectid);
		$categories = $this->knowledge_model->get_categories_projectid($projectid);
		$this->template->loadAjax("knowledge/ajax_categories.php", array(
			"categories" => $categories
			)
		);
	}


	public function categories($projectid = 0, $page = 0) 
	{	
		$this->template->loadExternal(
			'<link href="'.base_url().'scripts/libraries/chosen/chosen.min.css" rel="stylesheet" type="text/css">
			<script type="text/javascript" src="'.base_url().
			'scripts/libraries/chosen/chosen.jquery.min.js"></script>
			<script src="//cdn.ckeditor.com/4.5.8/standard/ckeditor.js">
			</script>'
		);
		$projectid = intval($projectid);
		$page = intval($page);
		if($projectid == 0) {
			$projectid = $this->user->info->active_projectid;
		}
		$this->template->loadData("activeLink", 
			array("knowledge" => array("categories" => 1)));

		$projects = $this->projects_model->get_all_projects_knowledge();
		$categories = $this->knowledge_model->get_categories($projectid, $page);


		// * Pagination *//
		$this->load->library('pagination');
		$config['base_url'] = site_url("knowledge/categories/" . $projectid);
		$config['total_rows'] = $this->knowledge_model
			->get_total_categories_count($projectid);
		$config['per_page'] = 15;
		$config['uri_segment'] = 4;
		include (APPPATH . "/config/page_config.php");
		$this->pagination->initialize($config);

		$this->template->loadContent("knowledge/categories.php", array(
			"projects" => $projects,
			"categories" => $categories
			)
		);
	}

	public function add_category() 
	{
		$this->load->library("upload");
		$name = $this->common->nohtml($this->input->post("name"));
		$description = $this->lib_filter->go($this->input->post("description"));
		

		if(empty($name)) {
			$this->template->error(lang("error_97"));
		}

		$uprojects = $this->input->post("projects");

		// Check ticket categories
		$projects= array();
		if($uprojects) {
			foreach($uprojects as $projectid) {
				$projectid = intval($projectid);
				if($projectid > 0) {
					$project = $this->projects_model->get_project($projectid);
					if($project->num_rows() == 0) {
						$this->template->error(lang("error_68"));
					}
					$project = $project->row();
					if(!$project->enable_knowledge) {
						$this->template->error(lang("error_95"));
					}
					$projects[] = $projectid;
				}
			}
		}

		// Add
		$catid = $this->knowledge_model->add_category(array(
			"name" => $name,
			"description" => $description,
			)
		);

		foreach($projects as $pid) {
			$this->knowledge_model->add_projects_to_cat($pid, $catid);
		}

		$this->session->set_flashdata("globalmsg", 
			lang("success_44"));
		redirect(site_url("knowledge/categories"));
	}

	public function delete_category($id, $hash) 
	{
		if($hash != $this->security->get_csrf_hash()) {
			$this->template->error(lang("error_6"));
		}
		$id = intval($id);
		$category = $this->knowledge_model->get_category($id);
		if($category->num_rows() == 0) {
			$this->template->error(lang("error_99"));
		}

		$this->knowledge_model->delete_category($id);
		$this->session->set_flashdata("globalmsg", 
			lang("success_45"));
		redirect(site_url("knowledge/categories"));
	}

	public function edit_category($id) 
	{
		$this->template->loadExternal(
			'<link href="'.base_url().'scripts/libraries/chosen/chosen.min.css" rel="stylesheet" type="text/css">
			<script type="text/javascript" src="'.base_url().
			'scripts/libraries/chosen/chosen.jquery.min.js"></script>
			<script src="//cdn.ckeditor.com/4.5.8/standard/ckeditor.js">
			</script>'
		);
		$this->template->loadData("activeLink", 
			array("knowledge" => array("categories" => 1)));

		$id = intval($id);
		$category = $this->knowledge_model->get_category($id);
		if($category->num_rows() == 0) {
			$this->template->error(lang("error_99"));
		}

		$projects = $this->knowledge_model->get_cat_projects($id);
		$this->template->loadContent("knowledge/edit_category.php", array(
			"projects" => $projects,
			"category" => $category->row()
			)
		);
	}

	public function edit_category_pro($id) 
	{
		$id = intval($id);
		$category = $this->knowledge_model->get_category($id);
		if($category->num_rows() == 0) {
			$this->template->error(lang("error_99"));
		}
		$category = $category->row();

		$this->load->library("upload");
		$name = $this->common->nohtml($this->input->post("name"));
		$description = $this->lib_filter->go($this->input->post("description"));
		

		if(empty($name)) {
			$this->template->error(lang("error_97"));
		}

		$uprojects = $this->input->post("projects");

		// Check ticket categories
		$projects= array();
		if($uprojects) {
			foreach($uprojects as $projectid) {
				$projectid = intval($projectid);
				if($projectid > 0) {
					$project = $this->projects_model->get_project($projectid);
					if($project->num_rows() == 0) {
						$this->template->error(lang("error_68"));
					}
					$project = $project->row();
					if(!$project->enable_knowledge) {
						$this->template->error(lang("error_95"));
					}
					$projects[] = $projectid;
				}
			}
		}

		// Add
		$this->knowledge_model->update_category($id, array(
			"name" => $name,
			"description" => $description
			)
		);

		$this->knowledge_model->delete_cat_projects($id);

		foreach($projects as $pid) {
			$this->knowledge_model->add_projects_to_cat($pid, $id);
		}

		$this->session->set_flashdata("globalmsg", 
			lang("success_46"));
		redirect(site_url("knowledge/categories"));
	}


}

?>