<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class News extends CI_Controller 
{

	public function __construct() 
	{
		parent::__construct();
		$this->load->model("user_model");
		$this->load->model("projects_model");
		$this->load->model("news_model");


		if(!$this->user->loggedin) {
			$this->template->error(lang("error_1"));
		}

		if(!$this->common->has_permissions(array("admin", "news_manage"), 
			$this->user)) {
			$this->template->error(lang("error_79"));
		}

		$this->template->loadData("activeLink", 
			array("news" => array("general" => 1)));
	
		// If the user does not have premium. 
		// -1 means they have unlimited premium
		if($this->settings->info->global_premium && 
			($this->user->info->premium_time != -1 && 
				$this->user->info->premium_time < time()) ) {
			$this->session->set_flashdata("globalmsg", lang("success_29"));
			redirect(site_url("funds/plans"));
		}
	}

	public function index($projectid =0) 
	{
		$projectid = intval($projectid);

		if($projectid == 0) {
			$projectid = $this->user->info->active_projectid;
		}

		$projects = $this->projects_model->get_all_projects_news();

		$this->template->loadContent("news/index.php", array(
			"projectid" => $projectid,
			"projects" => $projects
			)
		);
	}

	public function news_page($projectid = 0) 
	{
		$projectid = intval($projectid);

		if($projectid == 0) {
			$projectid = $this->user->info->active_projectid;
		}

		$this->load->library("datatables");

		$this->datatables->set_default_order("news.ID", "desc");

		// Set page ordering options that can be used
		$this->datatables->ordering(
			array(
				 0 => array(
				 	"news.title" => 0
				 ),
				 1 => array(
				 	"users.username" => 0
				 ),
				 2 => array(
				 	"projects.name" => 0
				 ),
				 3 => array(
				 	"news.updated" => 0
				 )

			)
		);

		$this->datatables->set_total_rows(
			$this->news_model
			->get_total_news_count($projectid)
		);
		$news = $this->news_model->get_news($projectid, $this->datatables);
		foreach($news->result() as $r) {

			$options = '';
			$options .='<a href="'. site_url("news/edit/" . $r->ID).'" class="btn btn-warning btn-xs" title="'.lang("ctn_55").'" data-toggle="tooltip" data-placement="bottom"><span class="glyphicon glyphicon-cog"></span></a> <a href="'. site_url("news/delete/" . $r->ID . "/" . $this->security->get_csrf_hash()) .'" class="btn btn-danger btn-xs" onclick="return confirm(\''.lang("ctn_317").'\')" title="'.lang("ctn_57").'" data-toggle="tooltip" data-placement="bottom"><span class="glyphicon glyphicon-trash"></span></a>';
			
			$this->datatables->data[] = array(
				$r->title,
				$this->common->get_user_display(array("username" => $r->username, "avatar" => $r->avatar, "online_timestamp" => $r->online_timestamp)),
				$r->project_name,
				date($this->settings->info->date_format, $r->updated),
				$options
			);
		}
		echo json_encode($this->datatables->process());
	}

	public function add() 
	{
		$this->template->loadExternal(
			'<script src="//cdn.ckeditor.com/4.5.8/standard/ckeditor.js">
			</script>'
		);

		// Get projects
		$projects = $this->projects_model->get_all_projects_news();
		$this->template->loadContent("news/add.php", array(
			"projects" => $projects
			)
		);

	}

	public function add_pro() 
	{
		$title = $this->common->nohtml($this->input->post("title"));
		$news = $this->lib_filter->go($this->input->post("news"));
		$projectid = intval($this->input->post("projectid"));

		if(empty($title)) {
			$this->template->error(lang("error_111"));
		}

		$project = $this->projects_model->get_project($projectid);
		if($project->num_rows() == 0) {
			$this->template->error(lang("error_68"));
		}
		$project = $project->row();
		if(!$project->enable_news) {
			$this->template->error(lang("error_112"));
		}

		$this->news_model->add_news(array(
			"userid" => $this->user->info->ID,
			"title" => $title,
			"news" => $news,
			"projectid" => $projectid,
			"timestamp" => time(),
			"updated" => time()
			)
		);

		$this->session->set_flashdata("globalmsg", lang("success_54"));
		redirect(site_url("news"));
	}

	public function delete($id, $hash) 
	{
		if($hash != $this->security->get_csrf_hash()) {
			$this->template->error(lang("error_6"));
		}
		$id = intval($id);
		$news = $this->news_model->get_news_item($id);
		if($news->num_rows() == 0) {
			$this->template->error(lang("error_113"));
		}
		$news = $news->row();

		$this->news_model->delete_news($id);
		$this->session->set_flashdata("globalmsg", lang("success_55"));
		redirect(site_url("news"));
	}

	public function edit($id) 
	{
		$id = intval($id);
		$news = $this->news_model->get_news_item($id);
		if($news->num_rows() == 0) {
			$this->template->error(lang("error_113"));
		}
		$news = $news->row();
		$this->template->loadExternal(
			'<script src="//cdn.ckeditor.com/4.5.8/standard/ckeditor.js">
			</script>'
		);

		// Get projects
		$projects = $this->projects_model->get_all_projects_news();
		$this->template->loadContent("news/edit.php", array(
			"projects" => $projects,
			"news" => $news
			)
		);
	}

	public function edit_pro($id) 
	{
		$id = intval($id);
		$news = $this->news_model->get_news_item($id);
		if($news->num_rows() == 0) {
			$this->template->error(lang("error_113"));
		}
		$news = $news->row();

		$title = $this->common->nohtml($this->input->post("title"));
		$news = $this->lib_filter->go($this->input->post("news"));
		$projectid = intval($this->input->post("projectid"));

		if(empty($title)) {
			$this->template->error(lang("error_111"));
		}

		$project = $this->projects_model->get_project($projectid);
		if($project->num_rows() == 0) {
			$this->template->error(lang("error_68"));
		}
		$project = $project->row();
		if(!$project->enable_news) {
			$this->template->error(lang("error_112"));
		}

		$this->news_model->update_news($id, array(
			"title" => $title,
			"news" => $news,
			"projectid" => $projectid,
			"updated" => time()
			)
		);

		$this->session->set_flashdata("globalmsg", lang("success_56"));
		redirect(site_url("news"));
	}

}

?>