<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class Projects extends CI_Controller 
{

	public function __construct() 
	{
		parent::__construct();
		$this->load->model("user_model");
		$this->load->model("projects_model");

		if(!$this->user->loggedin) {
			$this->template->error(lang("error_1"));
		}
		
		// If the user does not have premium. 
		// -1 means they have unlimited premium
		if($this->settings->info->global_premium && 
			($this->user->info->premium_time != -1 && 
				$this->user->info->premium_time < time()) ) {
			$this->session->set_flashdata("globalmsg", lang("success_29"));
			redirect(site_url("funds/plans"));
		}
	}

	public function index() 
	{
		$this->template->loadExternal(
			'<script src="//cdn.ckeditor.com/4.5.8/standard/ckeditor.js">
			</script>'
		);

		$this->template->loadData("activeLink", 
			array("projects" => array("general" => 1)));
		
		$this->template->loadContent("projects/index.php", array(
			)
		);
	}

	public function project_page() 
	{
		$this->load->library("datatables");

		$this->datatables->set_default_order("projects.ID", "desc");

		// Set page ordering options that can be used
		$this->datatables->ordering(
			array(
				 1 => array(
				 	"projects.name" => 0
				 ),
			)
		);

		$this->datatables->set_total_rows(
			$this->projects_model
				->get_total_projects_count()
		);
		$projects = $this->projects_model->get_projects($this->datatables);

		foreach($projects->result() as $r) {

			$project_name = $r->name;
			if($this->user->loggedin && $r->ID == $this->user->info->active_projectid) {
				$project_name .= ' <label class="label label-success">'.lang("ctn_452").'</label>';
			}

			$options = '<a href="'. site_url("projects/active_project/" . $r->ID) .'" class="btn btn-primary btn-xs">'.lang("ctn_453").'</a>';
			if($r->enable_documentation && ($this->common->has_permissions(array("admin", "documentation_manage"), $this->user)) ) {
				$options .= ' <a href="'.site_url("documents/index/" . $r->ID).'" class="btn btn-info btn-xs">'.lang("ctn_456").'</a>';
			}
			if($r->enable_knowledge && ($this->common->has_permissions(array("admin", "knowledge_manage"), $this->user)) ) {
				$options .= ' <a href="'.site_url("knowledge/index/" . $r->ID).'" class="btn btn-info btn-xs">'.lang("ctn_457").'</a>';
			}
			if($r->enable_contact && ($this->common->has_permissions(array("admin", "contact_manage"), $this->user)) ) {
				$options .= ' <a href="'.site_url("contact/index/" . $r->ID).'" class="btn btn-info btn-xs">'.lang("ctn_458").'</a>';
			}
			if($r->enable_news && ($this->common->has_permissions(array("admin", "news_manage"), $this->user)) ) {
				$options .= ' <a href="'.site_url("news/index/" . $r->ID).'" class="btn btn-info btn-xs">'.lang("ctn_498").'</a>';
			}
			if($this->common->has_permissions(array("admin", "project_manage"), $this->user)) {
				$options .= ' <a href="'.site_url("projects/edit_project/" . $r->ID).'" class="btn btn-warning btn-xs">'.lang("ctn_55").'</a> <a href="'.site_url("projects/delete_project/" . $r->ID . "/" . $this->security->get_csrf_hash()) .'" onclick="return confirm(\''.lang("ctn_405").'\')" class="btn btn-danger btn-xs">'.lang("ctn_57").'</a>';
			}

			$this->datatables->data[] = array(
				'<img src="'.base_url() . $this->settings->info->upload_path_relative .'/'.$r->image.'" width="20" height="20">',
				$project_name,
				'<a href="'.site_url("client/download/" . $r->ID).'" class="btn btn-default btn-xs">'.lang("ctn_454").'</a> <a href="'. site_url("client/view/" . $r->ID) .'" class="btn btn-default btn-xs">'. lang("ctn_455") .'</a>',
				$options

			);

		}
		echo json_encode($this->datatables->process());

	}

	public function edit_project($id) 
	{
		$this->template->loadExternal(
			'<script src="//cdn.ckeditor.com/4.5.8/standard/ckeditor.js">
			</script>'
		);
		$this->template->loadData("activeLink", 
			array("projects" => array("general" => 1)));
		if(!$this->common->has_permissions(array("admin", "project_manage"), 
			$this->user)) {
			$this->template->error(lang("error_79"));
		}
		$id = intval($id);
		$project = $this->projects_model->get_project($id);
		if($project->num_rows() == 0) {
			$this->template->error(lang("error_82"));
		}

		$this->template->loadContent("projects/edit.php", array(
			"project" => $project->row()
			)
		);
	}

	public function edit_project_pro($id) 
	{
		if(!$this->common->has_permissions(array("admin", "project_manage"), 
			$this->user)) {
			$this->template->error(lang("error_79"));
		}
		$id = intval($id);
		$project = $this->projects_model->get_project($id);
		if($project->num_rows() == 0) {
			$this->template->error(lang("error_82"));
		}
		$project = $project->row();

		$this->template->loadData("activeLink", 
			array("projects" => array("general" => 1)));

		$this->load->library("upload");
		$name = $this->common->nohtml($this->input->post("name"));
		$desc = $this->lib_filter->go($this->input->post("description"));

		$enable_documentation = intval($this->input->post("enable_documentation"));
		$enable_knowledge = intval($this->input->post("enable_knowledge"));
		$enable_contact = intval($this->input->post("enable_contact"));
		$enable_news = intval($this->input->post("enable_news"));
		$contact_email = $this->common->nohtml($this->input->post("contact_email"));

		$this->load->helper('email');

		if(!empty($contact_email)) {
			if(!valid_email($contact_email)) {
				$this->template->error(lang("error_104"));
			}
		}

		if (empty($name)) $this->template->error(lang("error_105"));

		if ($_FILES['userfile']['size'] > 0) {
			$this->upload->initialize(array( 
		       "upload_path" => $this->settings->info->upload_path,
		       "overwrite" => FALSE,
		       "max_filename" => 300,
		       "encrypt_name" => TRUE,
		       "remove_spaces" => TRUE,
		       "allowed_types" => "gif|jpg|png|jpeg|",
		       "max_size" => 1000,
		       "max_width" => 100,
		       "max_height" => 100
		    ));

		    if (!$this->upload->do_upload()) {
		    	$this->template->error("Upload Error: "
		    	.$this->upload->display_errors());
		    }

		    $data = $this->upload->data();

		    $image = $data['file_name'];
		} else {
			$image= $project->image;
		}

		$this->projects_model->update($id, array(
			"name" => $name, 
			"description" => $desc, 
			"image" => $image, 
			"userid" => $this->user->info->ID,
			"enable_documentation" => $enable_documentation,
			"enable_knowledge" => $enable_knowledge,
			"enable_contact" => $enable_contact,
			"contact_email" => $contact_email,
			"enable_news" => $enable_news
			)
		);
		$this->session->set_flashdata("globalmsg", 
			lang("success_47"));
		redirect(site_url("projects"));
	}

	public function active_project($id) 
	{
		$id = intval($id);
		if($id > 0) {
			$project = $this->projects_model->get_project($id);
			if($project->num_rows() == 0) {
				$this->template->error(lang("error_106"));
			}
		}

		// Make active
		$this->user_model->update_user($this->user->info->ID, array(
			"active_projectid" => $id
			)
		);
		$this->session->set_flashdata("globalmsg", 
			lang("success_48"));
		redirect(site_url("projects"));
	}

	public function create() 
	{
		if(!$this->common->has_permissions(array("admin", "project_manage"), 
			$this->user)) {
			$this->template->error(lang("error_69"));
		}
		$this->template->loadData("activeLink", 
			array("projects" => array("general" => 1)));

		$this->load->library("upload");
		$name = $this->common->nohtml($this->input->post("name"));
		$desc = $this->lib_filter->go($this->input->post("description"));

		$enable_documentation = intval($this->input->post("enable_documentation"));
		$enable_knowledge = intval($this->input->post("enable_knowledge"));
		$enable_contact = intval($this->input->post("enable_contact"));
		$enable_news = intval($this->input->post("enable_news"));
		$contact_email = $this->common->nohtml($this->input->post("contact_email"));

		$this->load->helper('email');

		if(!empty($contact_email)) {
			if(!valid_email($contact_email)) {
				$this->template->error(lang("error_104"));
			}
		}

		if (empty($name)) $this->template->error(lang("error_105"));

		if ($_FILES['userfile']['size'] > 0) {
			$this->upload->initialize(array( 
		       "upload_path" => $this->settings->info->upload_path,
		       "overwrite" => FALSE,
		       "max_filename" => 300,
		       "encrypt_name" => TRUE,
		       "remove_spaces" => TRUE,
		       "allowed_types" => "gif|jpg|png|jpeg|",
		       "max_size" => 1000,
		       "max_width" => 100,
		       "max_height" => 100
		    ));

		    if (!$this->upload->do_upload()) {
		    	$this->template->error("Upload Error: "
		    	.$this->upload->display_errors());
		    }

		    $data = $this->upload->data();

		    $image = $data['file_name'];
		} else {
			$image= $this->user->info->avatar;
		}

		$this->projects_model->create(array(
			"name" => $name, 
			"description" => $desc, 
			"image" => $image, 
			"userid" => $this->user->info->ID,
			"enable_documentation" => $enable_documentation,
			"enable_knowledge" => $enable_knowledge,
			"enable_contact" => $enable_contact,
			"contact_email" => $contact_email,
			"enable_news" => $enable_news
			)
		);
		$this->session->set_flashdata("globalmsg", 
			lang("success_49"));
		redirect(site_url("projects"));
	}

	public function delete_project($id, $hash) 
	{
		if($hash != $this->security->get_csrf_hash()) {
			$this->template->erorr(lang("error_6"));
		}
		if(!$this->common->has_permissions(array("admin", "project_manage"), 
			$this->user)) {
			$this->template->error(lang("error_79"));
		}
		$id = intval($id);
		$project = $this->projects_model->get_project($id);
		if($project->num_rows() == 0) {
			$this->template->error(lang("error_82"));
		}

		$this->projects_model->delete_project($id);
		$this->session->set_flashdata("globalmsg", 
			lang("success_50"));
		redirect(site_url("projects"));
	}

}

?>