<?php

class Knowledge_Model extends CI_Model 
{

	public function add_category($data) 
	{
		$this->db->insert("knowledge_categories", $data);
		return $this->db->insert_id();
	}

	public function get_categories($projectid, $page) 
	{
		if($projectid > 0) {
			$this->db->where("knowledge_categories.projectid", $projectid);
		}

		return $this->db
			->select("knowledge_categories.name, knowledge_categories.ID,
				knowledge_categories.description, knowledge_categories.icon,
				")
			->limit(15, $page)
			->order_by("knowledge_categories.ID", "DESC")
			->get("knowledge_categories");
	}

	public function get_categories_all() 
	{
		return $this->db
			->select("knowledge_categories.name, knowledge_categories.ID,
				knowledge_categories.description, knowledge_categories.icon,
				")
			->order_by("knowledge_categories.name")
			->get("knowledge_categories");
	}

	public function get_categories_projectid($projectid) 
	{
		return $this->db
			->where("knowledge_category_projects.projectid", $projectid)
			->select("knowledge_categories.ID, knowledge_categories.name, 
				knowledge_categories.description, knowledge_categories.icon")
			->join("knowledge_categories", "knowledge_categories.ID = knowledge_category_projects.catid")
			->get("knowledge_category_projects");
	}

	public function add_projects_to_cat($pid, $catid) 
	{
		$this->db->insert("knowledge_category_projects", array(
			"projectid" => $pid,
			"catid" => $catid
			)
		);
	}

	public function add_projects_to_article($pid, $articleid) 
	{
		$this->db->insert("knowledge_article_projects", array(
			"projectid" => $pid,
			"articleid" => $articleid
			)
		);
	}

	public function get_total_categories_count($projectid) 
	{
		if($projectid > 0) {
			$this->db->where("knowledge_categories.projectid", $projectid);
		}
		$s = $this->db->select("COUNT(*) as num")->get("knowledge_categories");
		$r = $s->row();
		if(isset($r->num)) return $r->num;
		return 0;
	}

	public function get_category($id) 
	{
		return $this->db->where("ID", $id)->get("knowledge_categories");
	}

	public function delete_category($id) 
	{
		$this->db->where("ID", $id)->delete("knowledge_categories");
	}

	public function update_category($id, $data) 
	{
		$this->db->where("ID", $id)->update("knowledge_categories", $data);
	}

	public function add_article($data) 
	{
		$this->db->insert("knowledge_articles", $data);
		return $this->db->insert_id();
	}

	public function get_articles($projectid, $catid, $datatable) 
	{
		$datatable->db_order();

		$datatable->db_search(array(
			"knowledge_articles.title",
			"users.username"
			)
		);

		if($catid > 0) {
			$this->db->where("knowledge_articles.categoryid", $catid);
		}
		if($projectid > 0) {
			$this->db->join("knowledge_article_projects", "knowledge_article_projects.articleid = knowledge_articles.ID AND knowledge_article_projects.projectid = " . $projectid);
		}
		return $this->db
			->select("knowledge_articles.ID, knowledge_articles.title, 
				knowledge_articles.userid, knowledge_articles.timestamp,
				knowledge_articles.article,
				knowledge_articles.last_updated, knowledge_articles.categoryid,
				knowledge_categories.name as cat_name, knowledge_articles.sticky,
				users.username, users.avatar, users.online_timestamp")
			->join("knowledge_categories", 
				"knowledge_categories.ID = knowledge_articles.categoryid")
			->join("users", "users.ID = knowledge_articles.userid")
			->limit($datatable->length, $datatable->start)
			->order_by("knowledge_articles.ID", "DESC")
			->get("knowledge_articles");
	}

	public function get_total_articles_count($projectid, $catid) 
	{
		if($projectid > 0) {
			$this->db->join("knowledge_article_projects", "knowledge_article_projects.articleid = knowledge_articles.ID AND knowledge_article_projects.projectid = " . $projectid);
		}
		if($catid > 0) {
			$this->db->where("knowledge_articles.categoryid", $catid);
		}
		$s = $this->db->select("COUNT(*) as num")
			->join("knowledge_categories", 
				"knowledge_categories.ID = knowledge_articles.categoryid")
			->get("knowledge_articles");
		$r = $s->row();
		if(isset($r->num)) return $r->num;
		return 0;
	}

	public function get_article($id) 
	{
		return $this->db
			->where("knowledge_articles.ID", $id)
			->select("knowledge_articles.ID, knowledge_articles.title, 
				knowledge_articles.userid, knowledge_articles.timestamp,
				knowledge_articles.last_updated, knowledge_articles.article,
				knowledge_articles.categoryid, knowledge_articles.sticky,
				knowledge_categories.name as cat_name,
				users.username")
			->join("knowledge_categories", 
				"knowledge_categories.ID = knowledge_articles.categoryid")
			->join("users", "users.ID = knowledge_articles.userid")
			->get("knowledge_articles");
	}

	public function delete_article($id) 
	{
		$this->db->where("ID", $id)->delete("knowledge_articles");
	}

	public function update_article($id, $data) 
	{
		$this->db->where("ID", $id)->update("knowledge_articles", $data);
	}


	public function get_articles_title($title) 
	{
		return $this->db
			->like("knowledge_articles.title", $title)
			->select("knowledge_articles.ID, knowledge_articles.title, 
				knowledge_articles.userid, knowledge_articles.timestamp,
				knowledge_articles.article,
				knowledge_articles.last_updated, knowledge_articles.categoryid,
				knowledge_categories.name as cat_name, knowledge_articles.sticky,
				projects.name as project_name, projects.ID as projectid,
				users.username")
			->join("knowledge_categories", 
				"knowledge_categories.ID = knowledge_articles.categoryid")
			->join("projects", "projects.ID = knowledge_categories.projectid")
			->join("users", "users.ID = knowledge_articles.userid")
			->limit(30)
			->order_by("knowledge_articles.ID", "DESC")
			->get("knowledge_articles");
	}

	public function get_articles_article($article) 
	{
		return $this->db
			->like("knowledge_articles.article", $article)
			->select("knowledge_articles.ID, knowledge_articles.title, 
				knowledge_articles.userid, knowledge_articles.timestamp,
				knowledge_articles.last_updated, knowledge_articles.categoryid,
				knowledge_articles.article,
				knowledge_categories.name as cat_name, knowledge_articles.sticky,
				projects.name as project_name, projects.ID as projectid,
				users.username")
			->join("knowledge_categories", 
				"knowledge_categories.ID = knowledge_articles.categoryid")
			->join("projects", "projects.ID = knowledge_categories.projectid")
			->join("users", "users.ID = knowledge_articles.userid")
			->limit(30)
			->order_by("knowledge_articles.ID", "DESC")
			->get("knowledge_articles");
	}

	public function get_recent_articles($projectid, $limit) 
	{
		return $this->db
			->where("knowledge_article_projects.projectid", $projectid)
			->select("knowledge_articles.ID, knowledge_articles.title, 
				knowledge_articles.article,
				knowledge_articles.userid, knowledge_articles.timestamp,
				knowledge_articles.last_updated, knowledge_articles.categoryid,
				knowledge_categories.name as cat_name, knowledge_articles.sticky,
				projects.name as project_name, projects.ID as projectid,
				users.username")
			->join("knowledge_articles", "knowledge_articles.ID = knowledge_article_projects.articleid")
			->join("knowledge_categories", "knowledge_categories.ID = knowledge_articles.categoryid")
			->join("projects", "projects.ID = knowledge_article_projects.projectid")
			->join("users", "users.ID = knowledge_articles.userid")
			->limit($limit)
			->order_by("knowledge_articles.ID")
			->get("knowledge_article_projects");
	}

	public function get_cat_projects($catid) 
	{
		return $this->db
			->select("projects.ID, projects.name, knowledge_category_projects.ID as cid")
			->join("knowledge_category_projects", "knowledge_category_projects.projectid = projects.ID AND knowledge_category_projects.catid = " . $catid, "left outer")
			->get("projects");
	}

	public function get_article_projects($articleid) 
	{
		return $this->db
			->select("projects.ID, projects.name, knowledge_article_projects.ID as cid")
			->join("knowledge_article_projects", "knowledge_article_projects.projectid = projects.ID AND knowledge_article_projects.articleid = " . $articleid, "left outer")
			->get("projects");
	}

	public function delete_cat_projects($catid) 
	{
		$this->db->where("catid", $catid)->delete("knowledge_category_projects");
	}

	public function delete_article_projects($articleid) 
	{
		$this->db->where("articleid", $articleid)->delete("knowledge_article_projects");
	}

	public function get_project_cat($projectid, $catid) 
	{
		return $this->db->where("projectid", $projectid)->where("catid", $catid)->get("knowledge_category_projects");
	}

}

?>